@@ -14,13 +14,16 @@
 #  limitations under the License.
 
 import blockdiag.elements
-from blockdiag.elements import DiagramEdge, unquote
 
 
 class DiagramNode(blockdiag.elements.DiagramNode):
     lane = None
 
 
+class DiagramEdge(blockdiag.elements.DiagramEdge):
+    pass
+
+
 class NodeGroup(blockdiag.elements.NodeGroup):
     def __init__(self, _id):
         super(NodeGroup, self).__init__(_id)
